"""
Stanford CS106AP Summer 2019
Campy Drawing Exercises
By Sonja Johnson-Yu, Kylie Jue, and Nick Bowman
Lecture 19, 7.25.19
"""
import sys
import random

from campy.graphics.gwindow import GWindow
from campy.graphics.gobjects import GOval, GLabel
from campy.gui.events.timer import pause

WIDTH = 600
HEIGHT = 400

NUM_SNOWMAN_PARTS = 3
SNOWMAN_SPACE = 50
BUBBLE_SPEED = 3
FRAME_SPEED = 1000 / 60    # 60 frames per second!


def get_blue_oval():
    """Returns a light blue circle of diameter 50"""
    oval = GOval(width=50, height=50)
    oval.filled = True
    oval.fill_color = "light_blue"
    return oval


def draw_bubbles(window, num_bubbles):
    """
    Draws given number of randomly placed bubbles.

    Inputs:
        window (GWindow): window object
        num_bubbles (int): number of bubbles to draw
    """
    for i in range(num_bubbles):
        bubble = get_blue_oval()
        x = random.randint(0, window.width - 1 - bubble.width)
        y = random.randint(0, window.height - 1 - bubble.height)
        window.add(bubble, x, y)


def animate_bubble_pop(window):
    """
    Draws a single bubble that floats to the top of the screen with some
    random, bubble-like x movements along the way.

    Inputs:
        window (GWindow): window object
    """
    bubble = get_blue_oval()
    x = random.randint(0, window.width - 1 - bubble.width)
    y = random.randint(0, window.height - 1 - bubble.height)
    window.add(bubble, x, y)
    while True:
        change_x = random.randint(-BUBBLE_SPEED, BUBBLE_SPEED)
        bubble.move(change_x, -BUBBLE_SPEED)
        if bubble.y <= 0:
            window.remove(bubble)
            break

            # Comment out break above and uncomment the lines below to create
            # never-ending bubbles!
            # x = random.randint(0, window.width - 1 - bubble.width)
            # y = random.randint(0, window.height - 1 - bubble.height)
            # window.add(bubble, x, y)
        pause(FRAME_SPEED)


def animate_many_bubbles(window, num_bubbles):
    """
    Draws many bubbles that floats the top of the screen with some
    random, bubble-like x movements along the way. Finishes when all
    bubbles have "popped."

    Inputs:
        window (GWindow): window object
        num_bubbles (int): number of bubbles to draw
    """
    bubbles = []
    for i in range(num_bubbles):
        bubble = get_blue_oval()
        x = random.randint(0, window.width - 1 - bubble.width)
        y = random.randint(0, window.height - 1 - bubble.height)
        window.add(bubble, x, y)
        bubbles.append(bubble)

    while True:
        if len(bubbles) == 0:
            finished = GLabel('No more bubbles!')
            finished_x = window.width / 2 - finished.width / 2
            finished_y = window.height / 2 - finished.height / 2
            window.add(finished, finished_x, finished_y)
            break

        for bubble in bubbles:
            change_x = random.randint(-BUBBLE_SPEED, BUBBLE_SPEED)
            bubble.move(change_x, -BUBBLE_SPEED)
            if bubble.y <= 0:
                window.remove(bubble)
                bubbles.remove(bubble)

        pause(FRAME_SPEED)


def main():
    args = sys.argv[1:]
    window = GWindow(height=HEIGHT, width=WIDTH, title='Bubbles')

    if len(args) == 2 and args[0] == '-bubbles':
        # usage: python3 Bubbles.py -bubbles n
        draw_bubbles(window, int(args[1]))
    elif len(args) == 1 and args[0] == '-onebubble':
        animate_bubble_pop(window)
    elif len(args) == 2 and args[0] == '-manybubbles':
        animate_many_bubbles(window, int(args[1]))



if __name__ == '__main__':
    main()
